# Question about boost field deprecation in 1.0.0.rc1

**URL:** <https://discuss.elastic.co/t/question-about-boost-field-deprecation-in-1-0-0-rc1/15691>\
**Category:** Elasticsearch\
**Created:** [February 10, 2014, 10:58am UTC](https://discuss.elastic.co/t/question-about-boost-field-deprecation-in-1-0-0-rc1/15691 "2014-02-10T10:58:40Z")\
**Posts on this page:** 3\
**Page:** 1

<div class="post-metadata">

**Author:** ![janosz\_krzysztof](https://avatars.discourse-cdn.com/v4/letter/j/97f17d/32.png) [@janosz\_krzysztof](https://discuss.elastic.co/u/janosz_krzysztof)\
**Post date:** [February 10, 2014, 10:58am UTC](https://discuss.elastic.co/t/question-about-boost-field-deprecation-in-1-0-0-rc1/15691/1 "2014-02-10T10:58:40Z")

</div>

Hello,

I have question about boost field deprecation in 1.x version. What should  
now be a proper way (with regards to performance) to achieve similar  
functionality?  
I've made some tests (using java api, in version 1.0.0.rc2) which was  
comparing quering using \_all field, MultiMatch and QueryString. Result were  
so, that \_all query was the fastest, while QueryString was ~1.9x times  
slower (and MultiMatch being from 2.5 to 3x times slower).  
So my question is, what should be the most appropriate way to replace text  
quering using \_all field boosted in index time by each included field?

Thanks in advance,  
Krzysztof Janosz

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
To view this discussion on the web visit [https://groups.google.com/d/msgid/elasticsearch/7ea54dd9-fbd7-4158-8900-18554df9aaf7%40googlegroups.com](https://groups.google.com/d/msgid/elasticsearch/7ea54dd9-fbd7-4158-8900-18554df9aaf7%40googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![janosz\_krzysztof](https://avatars.discourse-cdn.com/v4/letter/j/97f17d/32.png) [@janosz\_krzysztof](https://discuss.elastic.co/u/janosz_krzysztof)\
**Post date:** [February 17, 2014, 9:26am UTC](https://discuss.elastic.co/t/question-about-boost-field-deprecation-in-1-0-0-rc1/15691/2 "2014-02-17T09:26:51Z")

</div>

I've checked multi match with cross\_fields (sources compiled from master  
branch), and performance are so that query string is still better (~270ms  
per query compared to ~440ms in multi match) and still significantly  
noticeably worse than using \_all field (~140ms).

PS: Tests are done using java api and querying 1m record 1000 times in two  
cases (12 fields and 21 fields) with 10% query warmup.

Regards,  
Krzysztof Janosz

--  
You received this message because you are subscribed to the Google Groups "elasticsearch" group.  
To unsubscribe from this group and stop receiving emails from it, send an email to [elasticsearch+unsubscribe@googlegroups.com](mailto:elasticsearch+unsubscribe@googlegroups.com).  
To view this discussion on the web visit [https://groups.google.com/d/msgid/elasticsearch/d3b90075-201d-4c20-bf30-735b969fa36a%40googlegroups.com](https://groups.google.com/d/msgid/elasticsearch/d3b90075-201d-4c20-bf30-735b969fa36a%40googlegroups.com).  
For more options, visit [https://groups.google.com/groups/opt\_out](https://groups.google.com/groups/opt_out).

---

<div class="post-metadata">

**Author:** ![system](https://us1.discourse-cdn.com/elastic/original/3X/1/a/1ac57faf039f6b580b3f104ef42a2a89e41014de.png) [@system](https://discuss.elastic.co/u/system)\
**Post date:** [July 6, 2017, 1:49am UTC](https://discuss.elastic.co/t/question-about-boost-field-deprecation-in-1-0-0-rc1/15691/3 "2017-07-06T01:49:43Z")

</div>


